(************************************************************************
 *                                                                      *
 *   Ant Access Viewer                                                  *
 *   (C) 2002 Antoine Potten                                            *
 *   software@antp.be - http://www.antp.be/software                     *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *   This program is free software; you can redistribute it and/or      *
 *   modify it under the terms of the GNU General Public License        *
 *   as published by the Free Software Foundation; either version 2     *
 *   of the License, or (at your option) any later version.             *
 *                                                                      *
 *   This program is distributed in the hope that it will be useful,    *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of     *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
 *   GNU General Public License for more details.                       *
 *                                                                      *
 ************************************************************************)

unit ProgramSettings;

interface

uses
  SysUtils;

type

TSettings = class(TObject)
private
  FileName: TFileName;
public
  MainForm: record
    Left: Integer;
    Top: Integer;
    Width: Integer;
    Height: Integer;
    Maximized: Boolean;
  end;
  constructor Create(AFileName: TFileName);
  procedure Load;
  procedure Save;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

implementation

uses
  IniFiles;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

constructor TSettings.Create(AFileName: TFileName);
begin
  FileName := AFileName;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TSettings.Load;
begin
  with TMemIniFile.Create(FileName) do
    try
      with MainForm do
      begin
        Left := ReadInteger('MainForm', 'Left', -1);
        Top := ReadInteger('MainForm', 'Top', -1);
        Width := ReadInteger('MainForm', 'Width', 700);
        Height := ReadInteger('MainForm', 'Height', 500);
        Maximized := ReadBool('MainForm', 'Maximized', False);
      end;
    finally
      Free;
    end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TSettings.Save;
begin
  with TMemIniFile.Create(FileName) do
    try
      with MainForm do
      begin
        WriteInteger('MainForm', 'Left', Left);
        WriteInteger('M<ainForm', 'Top', Top);
        WriteInteger('MainForm', 'Width', Width);
        WriteInteger('MainForm', 'Height', Height);
        WriteBool('MainForm', 'Maximized', Maximized);
      end;
      UpdateFile;
    finally
      Free;
    end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

end.


