(************************************************************************
 *                                                                      *
 *   Ant Access Viewer                                                  *
 *   (C) 2002-2005 Antoine Potten                                       *
 *   software@antp.be - http://www.antp.be/software                     *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *   This program is free software; you can redistribute it and/or      *
 *   modify it under the terms of the GNU General Public License        *
 *   as published by the Free Software Foundation; either version 2     *
 *   of the License, or (at your option) any later version.             *
 *                                                                      *
 *   This program is distributed in the hope that it will be useful,    *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of     *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
 *   GNU General Public License for more details.                       *
 *                                                                      *
 ************************************************************************)

unit fMain;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, ToolWin, ActnList, ImgList, ADODB, DB, ExtCtrls,
  DBCtrls, Grids, DBGrids, StdCtrls,

  FileManager, Global;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

type
  TMainForm = class(TForm)
    CoolBar1: TCoolBar;
    ToolBar1: TToolBar;
    ToolButton1: TToolButton;
    ToolButton2: TToolButton;
    ActionList1: TActionList;
    ActionFileOpen: TAction;
    ActionFileClose: TAction;
    ImageList1: TImageList;
    ActionAbout: TAction;
    ActionExit: TAction;
    ToolButton3: TToolButton;
    ToolButton4: TToolButton;
    ToolButton5: TToolButton;
    ToolButton6: TToolButton;
    StatusBar1: TStatusBar;
    ADOConnection1: TADOConnection;
    ADOQuery1: TADOQuery;
    ToolButton7: TToolButton;
    DataSource1: TDataSource;
    TablesList: TListBox;
    Splitter1: TSplitter;
    Panel1: TPanel;
    DBGrid1: TDBGrid;
    Splitter2: TSplitter;
    SQLMemo: TMemo;
    ActionRefresh: TAction;
    ToolButton8: TToolButton;
    ActionRecordInsert: TAction;
    ActionRecordDelete: TAction;
    ToolButton9: TToolButton;
    ToolButton13: TToolButton;
    ActionSaveAs: TAction;
    ToolButton10: TToolButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ActionExitExecute(Sender: TObject);
    procedure ActionAboutExecute(Sender: TObject);
    procedure ActionFileOpenExecute(Sender: TObject);
    procedure ActionFileCloseExecute(Sender: TObject);
    procedure ActionRefreshExecute(Sender: TObject);
    procedure ActionRecordInsertExecute(Sender: TObject);
    procedure ActionRecordDeleteExecute(Sender: TObject);
    procedure TablesListClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure ActionSaveAsExecute(Sender: TObject);
  private
    FCurrentFile: TFileManager;
    procedure OnFileChange(Sender: TObject; AFileName: TFileName; var Result: Boolean);
    procedure OnFileOpen(Sender: TObject; AFileName: TFileName; var Result: Boolean);
    procedure OnFileNew(Sender: TObject; AFileName: TFileName; var Result: Boolean);
    procedure LoadOptions;
    procedure SaveOptions;
    procedure SaveToCSV(const Name: TFileName; const Delim: string);
  public
  end;

var
  MainForm: TMainForm;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

implementation

uses
  ConstValues, FAbout, ProgramSettings;

{$R *.dfm}

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.FormCreate(Sender: TObject);
begin
  FCurrentFile := TFileManager.Create(Self);
  with FCurrentFile do
  begin
    OnFileChange := Self.OnFileChange;
    OnOpenFile := Self.OnFileOpen;
    OnNewFile := Self.OnFileNew;
    OpenDialog.Filter := DialogDatabaseFilter;
    OpenDialog.Options := DialogOpenOptions;
  end;
  LoadOptions;
  if ParamCount = 0 then
    FCurrentFile.New
  else
    FCurrentFile.Open(ParamStr(1));
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  FCurrentFile.Free;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.OnFileChange(Sender: TObject; AFileName: TFileName; var Result: Boolean);
begin
  if AFileName = '' then
    AFileName := '<untitled>';
  Caption := Format('Ant Access Viewer - %s', [AFileName]);
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.OnFileOpen(Sender: TObject; AFileName: TFileName; var Result: Boolean);
begin
  try
    ADOConnection1.Connected := False;
    ADOConnection1.ConnectionString := Format(ConnectionString, [AFileName]);
    ADOConnection1.Connected := True;
    ADOConnection1.GetTableNames(TablesList.Items);
  except
    TablesList.Clear;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.OnFileNew(Sender: TObject; AFileName: TFileName; var Result: Boolean);
begin
  TablesList.Clear;
  ADOConnection1.Connected := False;
  ADOConnection1.ConnectionString := '';
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionExitExecute(Sender: TObject);
begin
  FCurrentFile.New;
  Close;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionAboutExecute(Sender: TObject);
begin
  with TAboutForm.Create(Self) do
    try
      ImageList1.GetIcon(ActionAbout.ImageIndex, Icon);
      ShowModal;
    finally
      Free;
    end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionFileOpenExecute(Sender: TObject);
begin
  FCurrentFile.Open;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionFileCloseExecute(Sender: TObject);
begin
  FCurrentFile.New;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionRefreshExecute(Sender: TObject);
begin
  ADOQuery1.Close;
  ADOQuery1.SQL.Assign(SQLMemo.Lines);
  ADOQuery1.Open;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionRecordInsertExecute(Sender: TObject);
begin
  ADOQuery1.Insert;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionRecordDeleteExecute(Sender: TObject);
begin
  ADOQuery1.Delete;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.TablesListClick(Sender: TObject);
var
  Idx: Integer;
begin
  Idx := TablesList.ItemIndex;
  if Idx > -1 then
  begin
    SQLMemo.Text := Format('SELECT * FROM `%s`;', [TablesList.Items[Idx]]);
    ActionRefresh.Execute;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  SaveOptions;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.LoadOptions;
begin
  with Settings.MainForm do
  begin
    if Maximized then
      Self.WindowState := wsMaximized
    else
    begin
      Self.Width := Width;
      Self.Height := Height;
      if (Left = -1) and (Top = -1) then
        Position := poScreenCenter
      else
      begin
        Self.Left := Left;
        Self.Top := Top;
      end;
    end;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.SaveOptions;
begin
  with Settings.MainForm do
  begin
    Maximized := WindowState = wsMaximized;
    if not Maximized then
    begin
      Width := Self.Width;
      Height := Self.Height;
      Left := Self.Left;
      Top := Self.Top;
    end;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.ActionSaveAsExecute(Sender: TObject);
var
  Idx: Integer;
begin
  Idx := TablesList.ItemIndex;
  if Idx > -1 then
  begin
    with TSaveDialog.Create(Self) do
    begin
      FileName := TablesList.Items[Idx];
      Options := DialogSaveOptions;
      Filter := DialogSaveFilter;
      if Execute then
        case FilterIndex of
          1:  SaveToCSV(FileName, #9);
          2:  SaveToCSV(FileName, ';');
          3:  ADOQuery1.SaveToFile(FileName, pfXML);
        end;
    end;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TMainForm.SaveToCSV(const Name: TFileName; const Delim: string);
var
  f: Textfile;
  s: string;
  i: Integer;
begin
  AssignFile(f, Name);
  FileMode := fmOpenWrite;
  Rewrite(f);
  ADOQuery1.First;
  s := '';
  for i := 0 to ADOQuery1.FieldCount-1 do
  begin
    if s <> '' then
      s := s + Delim;
    s := s + ADOQuery1.Fields[i].FieldName;
  end;
  WriteLn(f, s);
  while not ADOQuery1.Eof do
  begin
    s := '';
    for i := 0 to ADOQuery1.FieldCount-1 do
    begin
      if s <> '' then
        s := s + Delim;
      s := s + StringReplace(ADOQuery1.Fields[i].AsString, sLineBreak, '|', [rfReplaceAll]);
    end;
    WriteLn(f, s);
    ADOQuery1.Next;
  end;
  CloseFile(f);
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

end.
